%define	lib_major	6
%define	lib_name	%mklibname %{name} %{lib_major}
%define develname	%mklibname %{name} -d

Summary:	PARI/GP - Number Theory-oriented Computer Algebra System
Name:		pari
Version:	2.11.2
Release:	%mkrel 1
License:	GPLv2+
Group:		Sciences/Mathematics
URL:		http://pari.math.u-bordeaux.fr/
Source0:	http://pari.math.u-bordeaux.fr/pub/pari/unix/%{name}-%{version}.tar.xz
Source1:	http://pari.math.u-bordeaux.fr/pub/pari/packages/elldata.tgz
Source2:	http://pari.math.u-bordeaux.fr/pub/pari/packages/galdata.tgz
Source3:	http://pari.math.u-bordeaux.fr/pub/pari/packages/seadata.tgz
Source4:	http://pari.math.u-bordeaux.fr/pub/pari/packages/nftables.tgz
Source5:	http://pari.math.u-bordeaux.fr/pub/pari/packages/galpol.tgz
Patch0:		pari-arch.patch
Patch2:		pari-gphelp.patch
Patch3:		pari-runpath.patch
Patch4:		perl-warning-non-fatal.patch
Patch5:		pari-unescaped-left-brace.patch
BuildRequires:	perl-devel
BuildRequires:	libgmp-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	texlive
BuildRequires:	texlive-texmf
BuildRequires:	emacs
Requires:	perl
Requires:	xdg-utils
Requires:	%{name}-data = %{version}-%{release}

%description
PARI/GP is a widely used computer algebra system designed for fast
computations in number theory (factorizations, algebraic number theory,
elliptic curves...), but also contains a large number of other useful
functions to compute with mathematical entities such as matrices,
polynomials, power series, algebraic numbers, etc., and a lot of
transcendental functions. PARI is also available as a C library to allow
for faster computations.

%package	data
Group:		Sciences/Mathematics
Summary:	Optional pari data packages
Requires:	%{name} >= %{version}-%{release}
BuildArch:	noarch

%description	data
  elldata is PARI/GP version of J. E. Cremona Elliptic Curve Data,
needed by ellsearch and ellidentify.
  galdata is needed by polgalois to compute Galois group in degrees
8 through 11.
  seadata is needed by ellap for large primes.
  nftables is a repackaging of the historical megrez number field
tables (errors fixed, 1/10th the size, easier to use).

%package -n	%{lib_name}
Group:		System/Libraries
Summary:	Shared PARI library

%description -n	%{lib_name}
This package contains the libraries needed to run pari.

%package -n	%{develname}
Group:		Development/Libraries
Summary:	Development files for PARI shared library
Requires:	%{lib_name} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the header files needed to develop
applications using pari.

%prep
%setup -q -a1 -a2 -a3 -a4 -a5
mv -f nftables data
#autopatch -p1

%build
%define pkgdocdir	%{_docdir}/%{name}
%define pkgdatadir	%{_datadir}/%{name}-%{version}

sh Configure						\
	--prefix=%{_prefix}				\
	--includedir=%{_includedir}			\
	--datadir=%{pkgdatadir}/data			\
	--sysdatadir=%{_libdir}/%{name}			\
	--share-prefix=%{_datadir}			\
	--host=%{_arch}-%{_os}				\
	--graphic=X11					\
	--with-gmp					\
	--libdir=%{buildroot}%{_libdir}			\
	--disable-tls

echo "echo %_build_arch-%_build_os" > config/arch-osname

export PERL_USE_UNSAFE_INC=1
%ifarch %arm
%__make gp
%else
%__make bench
%endif

%__make doc

%install
# pari, libpari & libpari-devel
%make_install						\
	READMEDIR='$(DESTDIR)'%{pkgdocdir}		\
	LIBDIR='$(DESTDIR)'%{_libdir}			\
	DOCDIR='$(DESTDIR)'%{pkgdocdir}

# Install global configuration file.
mkdir %{buildroot}%{_sysconfdir}
# Add some more reasonable "commented" sample configurations
sed	-e 's@/usr/local/@%{_prefix}/@'				\
	-e 's@path =.*@path = "%{pkgdatadir}:.:~/gpdir"@'	\
	-e 's@lib/gpalias@misc/gpalias@'			\
	misc/gprc.dft > %{buildroot}/%{_sysconfdir}/gprc

# don't need to install this file...
rm -f %{buildroot}%{pkgdocdir}/*.{dvi,tex}
rm -f %{buildroot}%{pkgdocdir}/translations

# gphelp wants docs in %{pkgdatadir}/data/doc (removing the /data/ requirement)
ln -sf %{pkgdocdir} %{buildroot}%{pkgdatadir}/doc
perl -pi -e 's@%{pkgdatadir}/data@%{pkgdatadir}@;'		\
	%{buildroot}/%{_bindir}/gphelp

# remove %%{buildroot} from file contents
perl -pi -e 's@%{buildroot}@@g' \
	%{buildroot}%{_datadir}/%{name}-%{version}/data/examples/Makefile \
	%{buildroot}%{_libdir}/pari/pari.cfg

%files
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/gprc
%{_bindir}/gp-*
%{_bindir}/gp
%{_bindir}/gphelp
%{_bindir}/tex2mail
%{_mandir}/man1/[^g]*.1*
%{_mandir}/man1/gp.1*
%{_mandir}/man1/gp-*.1*
%{_mandir}/man1/gphelp.1*
%dir %{pkgdatadir}
%{pkgdatadir}/doc

%files	data
%dir %{pkgdatadir}/data
%{pkgdatadir}/data/*

%files	-n %{lib_name}
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.%{lib_major}

%files	-n %{develname}
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/%{name}/


%changelog
* Sat Jan 04 2020 tex - 2.11.2-1pclos2020
- create
